{% extends "users/base.html" %}
{% load crispy_forms_tags %}
{% block content %}
    <div class="content-section" style="color: white; margin-left: 5rem;">
        <form method="POST">
            {% csrf_token %}
            <fieldset class="form-group" style="border-width: 10px; font-size: 17px; padding-left: 30px;">
                <legend class="border-bottom mb-4" style="font-size: 40px;">Log In</legend>
                {{ form|crispy }}
                <div class="form-group" style="margin-top: 10px;">
                    <button class="primary-btn" type="submit">Login</button>
                    <small class = 'text-muted ml-2'>
                        <a href="{% url 'password_reset' %}">Forgot Password?</a>
                    </small>
                </div>
            </fieldset>
            
        </form>
        <div class="border-top pt-3" style="margin-bottom: 10px; margin-top: 10px; font-size: 17px;">
            <small class="text">
                Need An Account? <a class ="ml-2" href={% url 'register' %}>Sign Up Now</a>
            </small>
        </div>
    </div>
{% endblock content %}
